@@ -29,14 +29,14 @@ if not os.path.exists(EMPTY):
     os.makedirs(EMPTY)
 
 
-class DocumentNoSkip(Document):  # pylint: disable=R0904
+class DocumentNoSkip(Document):
 
     """Document class that is never skipped."""
 
     SKIP = '__disabled__'  # never skip test Documents
 
 
-class MockFileObject(BaseFileObject):  # pylint: disable=W0223,R0902,R0904
+class MockFileObject(BaseFileObject):  # pylint: disable=W0223,R0902
 
     """Mock FileObject class with stubbed file IO."""
 
@@ -47,7 +47,7 @@ class MockFileObject(BaseFileObject):  # pylint: disable=W0223,R0902,R0904
         self._read = Mock(side_effect=self._mock_read)
         self._write = Mock(side_effect=self._mock_write)
 
-    _new = Mock()
+    _create = Mock()
 
     def _mock_read(self, path):
         """Mock read method."""
@@ -66,31 +66,31 @@ class MockFileObject(BaseFileObject):  # pylint: disable=W0223,R0902,R0904
         return True
 
 
-class MockItem(MockFileObject, Item):  # pylint: disable=W0223,R0902,R0904
+class MockItem(MockFileObject, Item):  # pylint: disable=W0223,R0902
 
     """Mock Item class with stubbed file IO."""
 
 
-class MockDocument(MockFileObject, Document):  # pylint: disable=W0223,R0902,R0904
+class MockDocument(MockFileObject, Document):  # pylint: disable=W0223,R0902
 
     """Mock Document class with stubbed file IO."""
 
 
-class MockDocumentSkip(MockDocument):  # pylint: disable=W0223,R0902,R0904
+class MockDocumentSkip(MockDocument):  # pylint: disable=W0223,R0902
 
     """Mock Document class that is always skipped in tree placement."""
 
     skip = True
 
 
-class MockDocumentNoSkip(MockDocumentSkip):  # pylint: disable=W0223,R0902,R0904
+class MockDocumentNoSkip(MockDocumentSkip):  # pylint: disable=W0223,R0902
 
     """Mock Document class that is never skipped in tree placement."""
 
     SKIP = '__disabled__'  # never skip mock Documents
 
 
-class MockItemAndVCS(MockItem):  # pylint: disable=W0223,R0902,R0904
+class MockItemAndVCS(MockItem):  # pylint: disable=W0223,R0902
 
     """Mock item class with stubbed IO and a mock VCS reference."""
 
@@ -104,6 +104,16 @@ class MockDataMixIn:  # pylint: disable=W0232,R0903
 
     """Data for test cases requiring mock items and documents."""
 
+    # purely mock objects
+
+    mock_document = MagicMock()
+    mock_document.prefix = 'MOCK'
+    mock_document.items = []
+    mock_tree = MagicMock()
+    mock_tree.documents = [mock_document]
+
+    # mock objects that behave like the real thing
+
     item = MockItemAndVCS('path/to/req3.yml',
                           _file=("links: [sys3]" + '\n'
                                  "text: 'Heading'" + '\n'
@@ -115,14 +125,14 @@ class MockDataMixIn:  # pylint: disable=W0232,R0903
                                   ("Hello, world! " * 10) +
                                   "'\nlevel: 1.2"))
     _mock_item = Mock()
-    _mock_item.id = 'sys3'
+    _mock_item.uid = 'sys3'
     _mock_item.document.prefix = 'sys'
     item2.tree = Mock()
     item2.tree.find_item = Mock(return_value=_mock_item)
     _mock_item2 = Mock()
-    _mock_item2.id = 'tst1'
+    _mock_item2.uid = 'tst1'
     _mock_item2.document.prefix = 'tst'
-    item2.find_child_links = lambda: [MockDataMixIn._mock_item2.id]
+    item2.find_child_links = lambda: [MockDataMixIn._mock_item2.uid]
     item2.find_child_items = lambda: [MockDataMixIn._mock_item2]
 
     document = MagicMock(spec=['items'])
@@ -148,11 +158,13 @@ class MockDataMixIn:  # pylint: disable=W0232,R0903
         "level: 1.2" + '\n'
         "normative: true"))
     _mock_item3 = Mock()
-    _mock_item3.id = 'sys4'
+    _mock_item3.uid = 'sys4'
     _mock_item3.document.prefix = 'sys'
     item3.tree = Mock()
     item3.tree.find_item = Mock(return_value=_mock_item3)
-    item3.tree.vcs.ignored = (lambda _: False)
+    item3.tree.vcs.paths = [("Doorstop.sublime-project",
+                             "Doorstop.sublime-project",
+                             "Doorstop.sublime-project")]
 
     item4 = MockItemAndVCS('path/to/req3.yml',
                            _file=("links: [sys3]" + '\n'
@@ -160,3 +172,10 @@ class MockDataMixIn:  # pylint: disable=W0232,R0903
                                   "long: " + ('"' + '0' * 66 + '"') + '\n'
                                   "level: 1.1.0" + '\n'
                                   "normative: false"))
+
+    item5 = MockItemAndVCS('path/to/req3.yml',
+                           _file=("links: [sys3]" + '\n'
+                                  "text: 'Heading'" + '\n'
+                                  "level: 2.1.2" + '\n'
+                                  "normative: false" + '\n'
+                                  "ref: 'abc123'"))
