@@ -3,15 +3,19 @@
 import os
 import logging
 
+from doorstop import common
 from doorstop.common import DoorstopError
+from doorstop.core.vcs import git, subversion, veracity, mockvcs
 
-from doorstop.core.vcs import git
-from doorstop.core.vcs import veracity
-from doorstop.core.vcs import subversion
-from doorstop.core.vcs import mockvcs
+DEFAULT = mockvcs.WorkingCopy
+DIRECTORIES = {
+    git.WorkingCopy.DIRECTORY: git.WorkingCopy,
+    subversion.WorkingCopy.DIRECTORY: subversion.WorkingCopy,
+    veracity.WorkingCopy.DIRECTORY: veracity.WorkingCopy,
+    DEFAULT.DIRECTORY: DEFAULT,
+}
 
-from doorstop.core.vcs.base import BaseWorkingCopy as _bwc
-DIRECTORIES = {wc.DIRECTORY: wc for wc in _bwc.__subclasses__()}  # pylint: disable=E1101
+log = common.logger(__name__)
 
 
 def find_root(cwd):
@@ -26,8 +30,8 @@ def find_root(cwd):
     """
     path = cwd
 
-    logging.debug("looking for working copy from {}...".format(path))
-    logging.debug("options: {}".format(', '.join([d for d in DIRECTORIES])))
+    log.debug("looking for working copy from {}...".format(path))
+    log.debug("options: {}".format(', '.join([d for d in DIRECTORIES])))
     while not any(d in DIRECTORIES for d in os.listdir(path)):
         parent = os.path.dirname(path)
         if path == parent:
@@ -36,7 +40,7 @@ def find_root(cwd):
         else:
             path = parent
 
-    logging.debug("found working copy: {}".format(path))
+    log.debug("found working copy: {}".format(path))
     return path
 
 
@@ -45,5 +49,6 @@ def load(path):
     for directory in os.listdir(path):
         if directory in DIRECTORIES:
             return DIRECTORIES[directory](path)
-    logging.warning("no working copy found at: {}".format(path))
-    return mockvcs.WorkingCopy(path)
+
+    log.warning("no working copy found at: {}".format(path))
+    return DEFAULT(path)
